@@ -19,6 +19,7 @@ class LightdashChart(BaseModel):
     pinnedListUuid: Optional[str] = None
     spaceName: str
     chartType: Optional[str] = None
+    chartKind: Optional[str] = None
     dashboardUuid: Optional[str] = None
     dashboardName: Optional[str] = None
 
@@ -31,6 +32,7 @@ class LightdashDashboard(BaseModel):
     projectUuid: str
     updatedAt: str
     spaceUuid: str
+    spaceName: Optional[str] = None
     views: float
     firstViewedAt: str
     pinnedListUuid: Optional[str] = None
@@ -38,6 +40,15 @@ class LightdashDashboard(BaseModel):
     charts: Optional[List[LightdashChart]] = None
 
 
+class LightdashSpace(BaseModel):
+    organizationUuid: str
+    projectUuid: str
+    uuid: str
+    name: str
+    isPrivate: bool
+    parentSpaceUuid: Optional[str] = None
+
+
 class LightdashChartList(BaseModel):
     charts: Optional[List[LightdashChart]] = None
 
